package com.njyunzhi.h5.controller;

import com.njyunzhi.h5.common.ResponseBean;
import com.njyunzhi.h5.common.WxUtils;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.bean.WxJsapiSignature;
import me.chanjar.weixin.common.bean.WxOAuth2UserInfo;
import me.chanjar.weixin.common.bean.oauth2.WxOAuth2AccessToken;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/mp")
public class WxMpController {

    @Autowired
    WxUtils wxUtils;

    /**
     * 微信公众号接入
     * @param appid
     * @param signature
     * @param timestamp
     * @param nonce
     * @param echostr
     * @return
     */
    @GetMapping(path = "/portal/{appid}", produces = "text/plain;charset=utf-8")
    public String authGet(@PathVariable String appid,
                          @RequestParam(name = "signature", required = false) String signature,
                          @RequestParam(name = "timestamp", required = false) String timestamp,
                          @RequestParam(name = "nonce", required = false) String nonce,
                          @RequestParam(name = "echostr", required = false) String echostr) {
        return echostr;
    }

    @PostMapping(path = "/portal/{appid}", produces = "application/xml; charset=UTF-8")
    public String post(@PathVariable String appid,
                       @RequestBody String requestBody,
                       @RequestParam("signature") String signature,
                       @RequestParam("timestamp") String timestamp,
                       @RequestParam("nonce") String nonce,
                       @RequestParam("openid") String openid,
                       @RequestParam(name = "encrypt_type", required = false) String encType,
                       @RequestParam(name = "msg_signature", required = false) String msgSignature) {

        log.info("\n接收微信请求：[openid=[{}], [signature=[{}], encType=[{}], msgSignature=[{}],"
                        + " timestamp=[{}], nonce=[{}], requestBody=[\n{}\n] ",
                openid, signature, encType, msgSignature, timestamp, nonce, requestBody);

        return "";
    }

    @GetMapping("/jssdk")
    public ResponseBean jssdk(@RequestParam String url) throws Exception {
        WxJsapiSignature jsapiSignature = wxUtils.getMpService().createJsapiSignature(url);
        return ResponseBean.success(jsapiSignature);
    }


    @GetMapping({"/openid"})
    public ResponseBean openid(@RequestParam String code) throws Exception {
        WxOAuth2AccessToken accessToken = this.wxUtils.getMpService().getOAuth2Service().getAccessToken(code);
        return ResponseBean.success(accessToken.getOpenId());
    }

    @GetMapping({"/userinfo"})
    public ResponseBean userinfo(@RequestParam String code) throws Exception {
        WxOAuth2AccessToken accessToken = this.wxUtils.getMpService().getOAuth2Service().getAccessToken(code);
        WxOAuth2UserInfo wxMpUser = this.wxUtils.getMpService().getOAuth2Service().getUserInfo(accessToken, (String)null);
        return ResponseBean.success(wxMpUser);
    }
}
